==> rfishbase_2.1.2.tar.gz: rfishbase/inst/doc/tutorial.R <==
## ----include=FALSE-------------------------------------------------------
knitr::opts_chunk$set(warning=FALSE, comment=NA)

## ----message=FALSE, warning=FALSE, results="hide", eval=FALSE------------
#  remotes::install_github("ropensci/rfishbase")

## ----message=FALSE, warning=FALSE, results="hide", eval=FALSE------------
#  install.packages("rfishbase",
#                   repos = c("http://packages.ropensci.org", "http://cran.rstudio.com"),
#                   type="source")

## ----message=FALSE, warning=FALSE, results="hide"------------------------
library("rfishbase")

## ------------------------------------------------------------------------
fish <- c("Oreochromis niloticus", "Salmo trutta")

## ------------------------------------------------------------------------
fish <- validate_names(c("Oreochromis niloticus", "Salmo trutta"))

## ------------------------------------------------------------------------
fish <- species_list(Genus = "Labroides")
fish

## ------------------------------------------------------------------------
fish <- common_to_sci("trout")
fish

## ------------------------------------------------------------------------
species(fish[1:2])

## ------------------------------------------------------------------------
dat <- species(fish, fields=c("SpecCode", "PriceCateg", "Vulnerability"))
dat

## ------------------------------------------------------------------------
list_fields("Resilience")

## ------------------------------------------------------------------------
resil <- stocks(fish, fields="Resilience")
merge(dat, resil)

## ------------------------------------------------------------------------
options(FISHBASE_API = "https://fishbase.ropensci.org/sealifebase")
kingcrab <- common_to_sci("king crab")
kingcrab

## ----eval=FALSE----------------------------------------------------------
#  species(kingcrab)
#  ecology(kingcrab)

## ------------------------------------------------------------------------
options(FISHBASE_API = "https://fishbase.ropensci.org")

## ------------------------------------------------------------------------
kingcrab <- common_to_sci("king crab", server = "https://fishbase.ropensci.org/sealifebase")
kingcrab

==> rfishbase_3.0.0.tar.gz: rfishbase/inst/doc/tutorial.R <==
## ----include=FALSE-------------------------------------------------------
knitr::opts_chunk$set(warning=FALSE, comment=NA)

## ----message=FALSE, warning=FALSE, results="hide", eval=FALSE------------
#  remotes::install_github("ropensci/rfishbase")

## ----message=FALSE, warning=FALSE, results="hide"------------------------
library("rfishbase")

## ------------------------------------------------------------------------
fish <- c("Oreochromis niloticus", "Salmo trutta")

## ------------------------------------------------------------------------
fish <- validate_names(c("Oreochromis niloticus", "Salmo trutta"))

## ------------------------------------------------------------------------
fish <- species_list(Genus = "Labroides")
fish

## ------------------------------------------------------------------------
trout <- common_to_sci("trout")
trout

## ------------------------------------------------------------------------
species(trout$Species)

## ------------------------------------------------------------------------
dat <- species(trout$Species, fields=c("Species", "PriceCateg", "Vulnerability"))
dat

## ------------------------------------------------------------------------
list_fields("Resilience")

## ------------------------------------------------------------------------
stocks(trout$Species, fields=c("Species", "Resilience", "StockDefs"))

## ------------------------------------------------------------------------
Sys.setenv(FISHBASE_VERSION="17.07")

## ------------------------------------------------------------------------
load_taxa(server="sealifebase")

## ------------------------------------------------------------------------
species(server="sealifebase")
